Py4J
====

Py4J enables Python programs running in a Python interpreter to dynamically
access Java objects in a Java Virtual Machine. Methods are called as if the
Java objects resided in the Python interpreter and Java collections can be
accessed through standard Python collection methods. Py4J also enables Java
programs to call back Python objects.

The latest compiled release is available in the current-release directory.

This is the source repository of Py4J projects. Please visit the `Py4J homepage
<https://www.py4j.org>`_ for more information.

For help, register and then post to the Py4J mailing list at
``py4j at py4j dot org``

LICENSE
=======

Py4J is distributed with the BSD 3-Clause license. See LICENSE.txt for more
information.


CONTRIBUTING
============

We are always happy to receive code contributions, bug reports, and
documentation fixes. Please visit the `contributing guide
<https://www.py4j.org/contributing.html>`_ for more
information.

.. image:: https://circleci.com/gh/bartdag/py4j.svg?style=svg
    :target: https://circleci.com/gh/bartdag/py4
